@@ -155,16 +155,16 @@ initial_setup(void)
   book_canvas = GTK_IMAGE_VIEW(lookup_widget(MainWindow, "main_canvas"));
   image_buffer = g_malloc(pref.buffer_size);
 
-  /*readers[0] = g_archive_reader_unzip_new(image_buffer, 
+  readers[0] = g_archive_reader_unzip_new(image_buffer, 
 					  pref.buffer_size, 
-					  zip_magic);*/
+					  zip_magic);
   /* Note: if you have problems with the in-memory unzipper, use this
      one instead */
-  readers[0] = g_archive_reader_command_line_new(image_buffer, 
-      pref.buffer_size,
-      zip_magic,
-      zip_list_command,
-      zip_decompress_command);
+  /*readers[0] = g_archive_reader_command_line_new(image_buffer, 
+						 pref.buffer_size,
+						 zip_magic,
+						 zip_list_command,
+						 zip_decompress_command);*/
   readers[1] = g_archive_reader_command_line_new(image_buffer,
 						 pref.buffer_size,
 						 rar_magic,
